Why GraphQL?
============

GraphQL gives the following benefits:

- Allows clients to request what they want, if they only want a value without
  timestamp then they can do so
- Gives native support for subscriptions over websockets
- Does both of the above at the same time
- Is an industry standard

